@@ -6,11 +6,12 @@ import gmpy2
 import base64
 from Crypto.Cipher import AES as aes
 from Crypto.Util.number import long_to_bytes, bytes_to_long
+from typing import Optional, List
 
 
 class MiscUtils():
     """
-    本模块用于处理进制转换和常用哈希。
+    本模块用于处理进制转换和常用哈希。静态类，无需实例化。
     """
 
     @staticmethod
@@ -24,6 +25,7 @@ class MiscUtils():
         返回值：
             String (str): 转换得到的字符串
         """
+
         if len(Binary) % 8 != 0:
             raise Exception("二进制字符串的长度应该为8的倍数")
         String = "".join([chr(int(Binary[i:i + 8], 2)) for i in range(0, len(Binary), 8)])
@@ -40,6 +42,7 @@ class MiscUtils():
         返回值：
             Dec (int): 转换得到的十进制整数
         """
+
         Dec = int(Binary, 2)
         return Dec
 
@@ -54,6 +57,7 @@ class MiscUtils():
         返回值：
             Hex (str): 转换得到的十六进制字符串
         """
+
         Hex = hex(int(Binary, 2))
         return Hex
 
@@ -68,6 +72,7 @@ class MiscUtils():
         返回值：
             String (str): 转换得到的字符串
         """
+
         from Crypto.Util.number import long_to_bytes
         String = long_to_bytes(Dec).decode()
         return String
@@ -83,6 +88,7 @@ class MiscUtils():
         返回值：
             Binary (str): 转换得到的二进制字符串
         """
+
         Binary = bin(Dec)
         return Binary
 
@@ -97,6 +103,7 @@ class MiscUtils():
         返回值：
             Hex (str): 转换得到的十六进制字符串
         """
+
         Hex = hex(Dec)
         return Hex
 
@@ -111,6 +118,7 @@ class MiscUtils():
         返回值：
             String (str): 转换得到的字符串
         """
+
         if len(Hex) % 2 != 0:
             raise Exception("十六进制字符串的长度应该为2的倍数")
         String = "".join([chr(int(Hex[i:i + 2], 16)) for i in range(0, len(Hex), 2)])
@@ -127,6 +135,7 @@ class MiscUtils():
         返回值：
             Binary (str): 转换得到的二进制字符串
         """
+
         Binary = bin(int(Hex, 16))
         return Binary
 
@@ -141,6 +150,7 @@ class MiscUtils():
         返回值：
             Dec (int): 转换得到的十进制整数
         """
+
         Dec = int(Hex, 16)
         return Dec
 
@@ -155,6 +165,7 @@ class MiscUtils():
         返回值：
             Hash (str): 该字符串的 SHA1 哈希值（十六进制字符串，不含 0x 前缀）
         """
+
         from hashlib import sha1
         Hash = sha1(Text.encode()).hexdigest()
         return Hash
@@ -170,6 +181,7 @@ class MiscUtils():
         返回值：
             Hash (str): 该字符串的 SHA256 哈希值（十六进制字符串，不含 0x 前缀）
         """
+
         from hashlib import sha256
         Hash = sha256(Text.encode()).hexdigest()
         return Hash
@@ -185,6 +197,7 @@ class MiscUtils():
         返回值：
             Hash (str): 该字符串的 SHA512 哈希值（十六进制字符串，不含 0x 前缀）
         """
+
         from hashlib import sha512
         Hash = sha512(Text.encode()).hexdigest()
         return Hash
@@ -200,6 +213,7 @@ class MiscUtils():
         返回值：
             Hash (str): 该字符串的 MD5 哈希值（十六进制字符串，不含 0x 前缀）
         """
+
         from hashlib import md5
         Hash = md5(Text.encode()).hexdigest()
         return Hash
@@ -221,6 +235,7 @@ class ModernCryptoUtils():
         返回值：
             EncryptedText (str): Base64 编码后的字符串
         """
+
         EncryptedText = base64.b64encode(Text.encode()).decode()
         return EncryptedText
 
@@ -235,6 +250,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): Base64 解码后的字符串
         """
+
         DecryptedText = base64.b64decode(Text.encode()).decode()
         return DecryptedText
 
@@ -249,6 +265,7 @@ class ModernCryptoUtils():
         返回值：
             EncryptedText (str): Base32 编码后的字符串
         """
+
         EncryptedText = base64.b32encode(Text.upper().encode()).decode()
         return EncryptedText
 
@@ -263,6 +280,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): Base32 解码后的字符串
         """
+
         DecryptedText = base64.b32decode(Text.upper().encode()).decode()
         return DecryptedText
 
@@ -277,6 +295,7 @@ class ModernCryptoUtils():
         返回值：
             EncryptedText (str): Base16 编码后的字符串
         """
+
         EncryptedText = base64.b16encode(Text.upper().encode()).decode()
         return EncryptedText
 
@@ -291,6 +310,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): Base16 解码后的字符串
         """
+
         DecryptedText = base64.b16decode(Text.upper().encode()).decode()
         return DecryptedText
 
@@ -306,6 +326,7 @@ class ModernCryptoUtils():
         返回值：
             Fill (bytes): padding 后的字节数据
         """
+
         Fill = Text.encode()
         while len(Fill) % BlockSize != 0:
             Fill += b'\x00'
@@ -324,6 +345,7 @@ class ModernCryptoUtils():
         返回值：
             EncryptedText (str): AES 加密后的密文（Base64 编码形式）
         """
+
         AES = aes.new(ModernCryptoUtils.AES_Padding(Key, BlockSize), aes.MODE_ECB)
         EncryptedText = base64.b64encode(AES.encrypt(ModernCryptoUtils.AES_Padding(Text, BlockSize))).decode()
         return EncryptedText
@@ -341,6 +363,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): AES 解密后得到的原文
         """
+
         AES = aes.new(ModernCryptoUtils.AES_Padding(Key, BlockSize), aes.MODE_ECB)
         DecryptedText = AES.decrypt(base64.b64decode(ModernCryptoUtils.AES_Padding(Text, BlockSize))).decode()
         return DecryptedText
@@ -359,6 +382,7 @@ class ModernCryptoUtils():
         返回值：
             EncryptedText (str): RSA 加密后的密文（ Base64 编码形式）
         """
+
         m = bytes_to_long(Text.encode())
         c = gmpy2.powmod(m, e, p * q)
         EncryptedText = base64.b64encode(long_to_bytes(c)).decode()
@@ -378,6 +402,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): RSA 解密后得到的原文
         """
+
         c = bytes_to_long(base64.b64decode(Base64Text.encode()))
         d = gmpy2.invert(e, (p - 1) * (q - 1))
         m = gmpy2.powmod(c, d, p * q)
@@ -398,6 +423,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): RSA 解密后得到的原文
         """
+
         d = gmpy2.invert(e, (p - 1) * (q - 1))
         m = gmpy2.powmod(Long, d, p * q)
         DecryptedText = long_to_bytes(m).decode()
@@ -416,6 +442,7 @@ class ModernCryptoUtils():
         返回值：
             m (str): RSA 维纳攻击后得到的原文
         """
+
         def continuedFra(x, y):
             """
             计算连分数
@@ -427,6 +454,7 @@ class ModernCryptoUtils():
             返回值：
                 cf: 连分数列表
             """
+
             cf = []
             while y:
                 cf.append(x // y)
@@ -443,6 +471,7 @@ class ModernCryptoUtils():
             返回值：
                 numerator, denominator: 该列表最后的渐近分数（这里的渐进分数分子分母要分开）
             """
+
             numerator = 0
             denominator = 1
             for x in cf[::-1]:
@@ -461,6 +490,7 @@ class ModernCryptoUtils():
             返回值：
                 p, q: p 和 q 的值
             """
+
             par = gmpy2.isqrt(b * b - 4 * a * c)
             return (-b + par) // (2 * a), (-b - par) // (2 * a)
 
@@ -474,6 +504,7 @@ class ModernCryptoUtils():
             返回值：
                 gf: 该列表所有的渐近分数
             """
+
             gf = []
             for i in range(1, len(cf) + 1):
                 gf.append(gradualFra(cf[:i]))
@@ -493,7 +524,7 @@ class ModernCryptoUtils():
                 return m
 
     @staticmethod
-    def RSA_MultiPrime_Attack(c: int, e: int, n: int, primes: list, powers: list = None) -> str:
+    def RSA_MultiPrime_Attack(c: int, e: int, n: int, primes: List[int], powers: Optional[List[int]] = None) -> str:
         """
         用于对长整数形式的 RSA 密文进行多素数攻击并解出原文。
 
@@ -502,11 +533,12 @@ class ModernCryptoUtils():
             e (int): e 值
             n (int): n 值
             primes (List[int]): 用于攻击的多素数列表
-            powers (可选)(List[int]): 各素数对应的阶数，默认均为 1 次方
+            powers (Optional[List[int]]): 各素数对应的阶数，默认均为 1 次方
 
         返回值：
             m (str): RSA 多素数攻击后得到的原文
         """
+
         from operator import mul
         from functools import reduce
         if powers == None:
@@ -532,6 +564,7 @@ class ModernCryptoUtils():
         返回值：
             m (str): RSA 低加密指数攻击后得到的原文
         """
+
         k = 0
         while k < 10**5:
             m = gmpy2.iroot(c + k * n, e)[0]
@@ -558,12 +591,13 @@ class ModernCryptoUtils():
         返回值：
             m (str): RSA 共模攻击后得到的原文
         """
+
         _, x, y = gmpy2.gcdext(e1, e2)
         m = long_to_bytes((gmpy2.powmod(c1, x, n) * gmpy2.powmod(c2, y, n)) % n).decode()
         return m
 
     @staticmethod
-    def RSA_Broadcast_Attack(cs: list, e: int, ns: list) -> str:
+    def RSA_Broadcast_Attack(cs: List[int], e: int, ns: List[int]) -> str:
         """
         用于对长整数形式的 RSA 密文列表进行广播攻击并解出原文。
 
@@ -575,6 +609,7 @@ class ModernCryptoUtils():
         返回值：
             m (str): RSA 广播攻击后得到的原文
         """
+
         from functools import reduce
         if len(cs) != len(ns):
             raise Exception("密文列表长度与 n 值列表长度不一致")
@@ -599,6 +634,7 @@ class ModernCryptoUtils():
         返回值：
             EncryptedText (str): RC4 加密后得到的密文（ Base64 编码形式）
         """
+
         from Crypto.Cipher import ARC4
         RC4 = ARC4.new(Key.encode())
         EncryptedText = base64.b64encode(RC4.encrypt(Text.encode())).decode()
@@ -616,6 +652,7 @@ class ModernCryptoUtils():
         返回值：
             DecryptedText (str): RC4 解密后得到的原文
         """
+
         from Crypto.Cipher import ARC4
         RC4 = ARC4.new(Key.encode())
         DecryptedText = RC4.decrypt(base64.b64decode(Text.encode())).decode()
@@ -634,11 +671,12 @@ class ClassicalCryptoUtils():
 
         参数：
             Text (str): 待进行 Caesar 加密的字符串
-            Move (int): 移位位数，默认为 3 
+            Move (可选)(int): 移位位数，默认为 3 
 
         返回值：
             EncryptedText (str): Caesar 加密后得到的密文
         """
+
         EncryptedText = ""
         for i in Text:
             if i.isupper():
@@ -656,11 +694,12 @@ class ClassicalCryptoUtils():
 
         参数：
             Text (str): 待进行解密的 Caesar 密文
-            Move (int): 移位位数，默认为 3 
+            Move (可选)(int): 移位位数，默认为 3 
 
         返回值：
             DecryptedText (str): Caesar 解密后得到的原文
         """
+
         DecryptedText = ""
         for i in Text:
             if i.isupper():
@@ -672,7 +711,7 @@ class ClassicalCryptoUtils():
         return DecryptedText
 
     @staticmethod
-    def Caesar_Attack(Text: str) -> list:
+    def Caesar_Attack(Text: str) -> List[str]:
         """
         用于对 Caesar 密文进行爆破攻击。
 
@@ -682,6 +721,7 @@ class ClassicalCryptoUtils():
         返回值：
             Result (List[str]): Caesar 爆破攻击后得到的字符串列表
         """
+
         Result = [ClassicalCryptoUtils.Caesar_Decrypt(Text, i) for i in range(1, 27)]
         return Result
 
@@ -696,6 +736,7 @@ class ClassicalCryptoUtils():
         返回值：
             EncryptedText (str): Morse 加密后得到的密文（未找到映射关系的字符将保持不变）
         """
+
         MorseCode = {
             "A": ".-", "B": "-...", "C": "-.-.", "D": "-..", "E": ".", "F": "..-.", "G": "--.",
             "H": "....", "I": "..", "J": ".---", "K": "-.-", "L": ".-..", "M": "--",
@@ -725,6 +766,7 @@ class ClassicalCryptoUtils():
         返回值：
             DecryptedText (str): Morse 解密后得到的原文（未找到映射关系的字符将保持不变）
         """
+
         MorseCode = {
             ".-": "a", "-...": "b", "-.-.": "c", "-..": "d", ".": "e", "..-.": "f",
             "--.": "g", "....": "h", "..": "i", ".---": "j", "-.-": "k", ".-..": "l",
@@ -750,6 +792,7 @@ class ClassicalCryptoUtils():
         返回值：
             EncryptedText (str): Bacon 加密后得到的密文（大写形式 未找到映射关系的字符将以[]包裹）
         """
+
         BaconCode = {
             "a": "aaaaa", "b": "aaaab", "c": "aaaba", "d": "aaabb", "e": "aabaa", "f": "aabab", "g": "aabba",
             "h": "aabbb", "i": "abaaa", "j": "abaab", "k": "ababa", "l": "ababb", "m": "abbaa", "n": "abbab",
@@ -770,6 +813,7 @@ class ClassicalCryptoUtils():
         返回值：
             DecryptedText (str): Bacon 解密后得到的原文（大写形式 未找到映射关系的字符将以[]包裹）
         """
+
         if len(Text) % 5 != 0:
             raise Exception("Bacon 密文应该为 5 的倍数")
         BaconCode = {
@@ -794,6 +838,7 @@ class ClassicalCryptoUtils():
         返回值：
             EncryptedText (str): Fence 加密后得到的密文
         """
+
         if len(Text) % Fence != 0:
             raise Exception("字符串长度应该为栏数的倍数")
         templist = []
@@ -818,6 +863,7 @@ class ClassicalCryptoUtils():
         返回值：
             DecryptedText (str): Fence 解密后得到的原文
         """
+
         if len(Text) % Fence != 0:
             raise Exception("字符串长度应该为栏数的倍数")
         templist = ["" for _ in range(Fence)]
@@ -829,7 +875,7 @@ class ClassicalCryptoUtils():
         return DecryptedText
 
     @staticmethod
-    def Fence_Attack(Text: str) -> list:
+    def Fence_Attack(Text: str) -> List[tuple]:
         """
         用于对 Fence 密文进行爆破攻击。
 
@@ -839,12 +885,13 @@ class ClassicalCryptoUtils():
         返回值：
             Result (List[tuple]): Fence 爆破攻击后得到的元组列表（字符串, 栏数）
         """
+
         Factors = [factor for factor in range(2, len(Text)) if len(Text) % factor == 0]
         Result = [(ClassicalCryptoUtils.Fence_Decrypt(Text, i), i) for i in Factors]
         return Result
 
     @staticmethod
-    def WFence_Generate(Text: str, Fence: int) -> list:
+    def WFence_Generate(Text: str, Fence: int) -> List[List[str]]:
         """
         用于生成 WFence 矩阵以便后续处理。
 
@@ -855,6 +902,7 @@ class ClassicalCryptoUtils():
         返回值：
             Matrix (List[List[str]]): 生成的 WFence 矩阵
         """
+
         Matrix = [['.'] * len(Text) for _ in range(Fence)]
         Row = 0
         Up = False
@@ -882,6 +930,7 @@ class ClassicalCryptoUtils():
         返回值：
             EncryptedText (str): WFence 加密后得到的密文
         """
+
         Matrix = ClassicalCryptoUtils.WFence_Generate(Text, Fence)
         EncryptedText = ""
         for Row in range(Fence):
@@ -902,6 +951,7 @@ class ClassicalCryptoUtils():
         返回值：
             DecryptedText (str): WFence 解密后得到的原文
         """
+
         Matrix = ClassicalCryptoUtils.WFence_Generate(Text, Fence)
         index = 0
         for Row in range(Fence):
@@ -917,7 +967,7 @@ class ClassicalCryptoUtils():
         return DecryptedText
 
     @staticmethod
-    def WFence_Attack(Text: str) -> list:
+    def WFence_Attack(Text: str) -> List[tuple]:
         """
         用于对 WFence 密文进行爆破攻击。
 
@@ -927,5 +977,6 @@ class ClassicalCryptoUtils():
         返回值：
             Result (List[tuple]): WFence 爆破攻击后得到的元组列表（字符串, 栏数）
         """
+
         Result = [(ClassicalCryptoUtils.WFence_Decrypt(Text, i), i) for i in range(2, len(Text))]
         return Result
